package FreeBSD::Ports::DistilatorThreaded;

use strict;
use warnings;

use threads;

use FreeBSD::Ports::DistilatorCommon;
use File::Basename;
use HTTP::SimpleLinkChecker;

our (@ISA, @EXPORT_OK, @EXPORT);
BEGIN {
        require Exporter;
        @ISA = qw(Exporter);
        @EXPORT = qw(usage validate_single_port);
}

# flush after every write
$|=1;

sub usage {
        my($class)=@_;
        printf(<< "__ENOUSAGE__", basename($0), $class->{'VERSION'}, basename($0));
%s version %s
(threaded version)

Usage: %s [OPTION] PORT

Options
 -h, --help              this help
     --threads NUM       number of concurrent threads
     --timeout NUM       link check timeout
 -v, --version           print version

__ENOUSAGE__
        return 0;
}

sub validate($$) {
	my($defcfg,$job)=@_;
	my %res=('code' => undef, 'has_timed_out' => undef, 'link' => $job->{'link'}, 'type' => $job->{'type'});
	my $ua=HTTP::SimpleLinkChecker::user_agent();
	$ua->timeout($defcfg->{'link_check_timeout'});
	$ua->agent(get_random_user_agent());

	eval {
		local $SIG{ALRM} = sub {$res{'has_timed_out'}=1; die "alarm\n"};
		alarm $defcfg->{'link_check_timeout'};
		$res{'code'}=HTTP::SimpleLinkChecker::check_link($job->{'link'});
		alarm 0;
	};

	printResult(\%res);

	threads->detach();
}

sub validate_single_port($$) {
	my($defcfg,$port)=@_;
	my $urls=get_urls($defcfg,$port);
	my @jobs;
	while(my($link,$type)=each(%$urls)) {
		push(@jobs, {'link' => $link, 'type' => $type});
	}

	while(@jobs) {
		for(1 .. $defcfg->{'max_threads'} - threads->list() ) {
			my $job=shift(@jobs);
			last if(!$job);
			threads->create('validate',$defcfg,$job);
		}
	}

	while(threads->list() > 0) {
		1;
	}
}

1;
